@@ -151,6 +151,8 @@ void init_config(ConfigCollection* collection) {
 #ifdef __OS2__
 	strarg->setDefault("vlatexp.cmd");
 #endif
+	section->addStringOption("latex_options", GLE_TOOL_LATEX_OPTIONS);
+
 	/* PdfLaTeX */
 	strarg = section->addStringOption("pdflatex", GLE_TOOL_PDFTEX_CMD);
 #ifdef __WIN32__
@@ -158,6 +160,8 @@ void init_config(ConfigCollection* collection) {
 #else
 	strarg->setDefault("pdflatex");
 #endif
+	section->addStringOption("pdflatex_options", GLE_TOOL_PDFTEX_OPTIONS);
+
 	/* DVIPS */
 	strarg = section->addStringOption("dvips", GLE_TOOL_DVIPS_CMD);
 #ifdef __WIN32__
@@ -169,6 +173,8 @@ void init_config(ConfigCollection* collection) {
 #ifdef __OS2__
 	strarg->setDefault("dvips.exe");
 #endif
+	section->addStringOption("dvips_options", GLE_TOOL_DVIPS_OPTIONS);
+
 	/* GhostScript Program */
 	strarg = section->addStringOption("ghostscript", GLE_TOOL_GHOSTSCRIPT_CMD);
 #ifdef __WIN32__
@@ -183,6 +189,8 @@ void init_config(ConfigCollection* collection) {
 #ifdef __OS2__
 	strarg->setDefault("gsos2.exe");
 #endif
+	section->addStringOption("ghostscript_options", GLE_TOOL_GHOSTSCRIPT_OPTIONS);
+
 	collection->addSection(section, GLE_CONFIG_TOOLS);
 	/* GhostScript Library */
 	strarg = section->addStringOption("libgs", GLE_TOOL_GHOSTSCRIPT_LIB);
@@ -293,6 +301,7 @@ void get_version_soft(const string& cmdline, string& version) {
 	string gle_output;
 	GLERunCommand(cmdline, gle_output);
 	str_parse_get_next(gle_output, "VERSION", version);
+	str_remove_quote(version);
 }
 
 void get_version_hard(const string& cmdline, string& version) {
@@ -370,7 +379,7 @@ void GLEProgressIndicatorInterface::indicate() {
 }
 
 string get_tool_path(int tool, ConfigSection* tools) {
-	string path = ((CmdLineArgString*)tools->getOptionValue(tool))->getValue();
+	string path(tools->getOptionString(tool));
 	string::size_type pos = path.find(',');
 	if (pos != string::npos) {
 		path.erase(pos);
@@ -380,7 +389,7 @@ string get_tool_path(int tool, ConfigSection* tools) {
 		path.erase(pos);
 	}
 	str_replace_all(path, "$EXELOC", GLE_BIN_DIR.c_str());
-	return path;
+	return GLEExpandEnvironmentVariables(path);
 }
 
 void find_deps(const string& loc, GLEInterface* iface) {
@@ -427,9 +436,21 @@ void find_deps(const string& loc, GLEInterface* iface) {
 	GLEProgressIndicatorInterface progress(iface);
 	// Perform search at specified location
 	if (loc != "") {
-		GLEFindFiles(loc, tofind, &progress);
-		for (unsigned int i = 0; i < tofind.size(); i++) {
-			tofind[i]->updateResult(false);
+		if (IsDirectory(loc, true)) {
+			GLEFindFiles(loc, tofind, &progress);
+			for (unsigned int i = 0; i < tofind.size(); i++) {
+				tofind[i]->updateResult(false);
+			}
+		} else {
+			// Name of old GLERC file given
+			if (try_load_config(loc)) {
+				// Override old version number
+				collection->setStringValue(GLE_CONFIG_GLE, GLE_CONFIG_GLE_VERSION, GLEVN);
+			} else {
+				ostringstream err;
+				err << "Can't load configuration from '" << loc << "'" << endl;
+				output->println(err.str().c_str());
+			}
 		}
 	}
 	#ifdef __UNIX__
