@@ -222,17 +222,11 @@ bool str_ni_equals(const char* s1, const char* s2, int max) {
 }
 
 int str_i_cmp(const char* s1, const char* s2) {
-        char* s1_copy = new char[strlen(s1) + 1];
-        strcpy(s1_copy, s1);
-
-        char* s2_copy = new char[strlen(s2) + 1];
-        strcpy(s2_copy, s2);
-
-        int result = strcmp(gle_strupr(s1_copy), gle_strupr(s2_copy));
-        delete[] s1_copy;
-        delete[] s2_copy;
-
-        return result;
+	while (true) {
+		int c1 = tolower((unsigned char)*(s1++));
+		int c2 = tolower((unsigned char)*(s2++));
+		if (c1 == 0 || c1 != c2) return c1 - c2;
+	}
 }
 
 int str_i_str(const string& haystack, int from, const char* needle) {
