@@ -1471,3 +1471,37 @@ string gledir(const char *fname) {
 	result += fname;
 	return result;
 }
+
+string GLEExpandEnvironmentVariables(const string& str) {
+	ostringstream result;
+	for (unsigned int i = 0; i < str.size(); i++) {
+		if (str[i] == '$') {
+			string envVar;
+			for (unsigned int j = i+1; j < str.size(); j++) {
+				if (toupper(str[j]) >= 'A' && toupper(str[j]) <= 'Z') {
+					envVar += str[j];
+				} else {
+					break;
+				}
+			}
+			bool replaced = false;
+			if (!envVar.empty()) {
+				char* var = getenv(envVar.c_str());
+				if (var != NULL) {
+					replaced = true;
+					result << var;
+				}
+			}
+			if (!replaced) {
+				result << "$";
+				result << envVar;
+			}
+			i += envVar.size();
+		} else {
+			result << str[i];
+		}
+	}
+	return result.str();
+}
+
+
