@@ -921,6 +921,10 @@ bool GLEDrawObject::approx(GLEDrawObject* other) {
 void GLEDrawObject::draw() {
 }
 
+bool GLEDrawObject::modified() {
+	return true;
+}
+
 void GLEDrawObject::setProperties(GLEPropertyStore* store) {
 	if (m_Properties != NULL) delete m_Properties;
 	m_Properties = store;
@@ -1041,6 +1045,7 @@ GLEDrawObject* GLEScript::newGLEObject(GLEDrawObjectType type) {
 			break;
 		case GDOText:
 			obj = new GLETextDO();
+			((GLETextDO*)obj)->setModified(true);
 			obj->initProperties(GLEGetInterfacePointer());
 			break;
 		default:
@@ -1083,6 +1088,7 @@ void GLEScript::updateObjectDOConstructors() {
 	GLESubMap* subs = getParser()->getSubroutines();
 	for (int i = 0; i < subs->size(); i++) {
 		GLESub* sub = subs->get(i);
+		sub->setScript(this);
 		bool okSub = true;
 		if (!sub->isObject()) {
 			okSub = false;
@@ -1093,7 +1099,6 @@ void GLEScript::updateObjectDOConstructors() {
 			}
 		}
 		if (okSub) {
-			sub->setScript(this);
 			int line = sub->getStart();
 			GLESourceFile* file = m_File.getLine(line)->getSource();
 			GLEObjectDOConstructor* cons = sub->getObjectDOConstructor();
@@ -1368,10 +1373,10 @@ GLEPoint& GLEArcDO::getPointMid(GLEPoint& pt) {
 	return pt;
 }
 
-GLETextDO::GLETextDO() {
+GLETextDO::GLETextDO() : m_Modified(false) {
 }
 
-GLETextDO::GLETextDO(GLEPoint& position, const string& text) : m_Position(position), m_Text(text) {
+GLETextDO::GLETextDO(GLEPoint& position, const string& text) : m_Position(position), m_Text(text), m_Modified(false) {
 }
 
 GLETextDO::~GLETextDO() {
@@ -1439,6 +1444,14 @@ bool GLETextDO::approx(GLEDrawObject* other) {
 	       m_Text == othert->getText();
 }
 
+bool GLETextDO::modified() {
+	return m_Modified;
+}
+
+void GLETextDO::setModified(bool modified) {
+	m_Modified = modified;
+}
+
 void GLETextDO::initProperties(GLEInterface* iface) {
 	int justify;
 	m_Properties = new GLEPropertyStore(iface->getTextPropertyStoreModel());
@@ -1454,6 +1467,7 @@ void GLETextDO::render(GLEInterface* iface) {
 
 GLEObjectDO::GLEObjectDO(GLEObjectDOConstructor* cons) {
 	m_Cons = cons;
+	setRefPointString(GLEString::getEmptyString());
 }
 
 GLEObjectDO::~GLEObjectDO() {
