@@ -841,6 +841,7 @@ public:
 	virtual void applyTransformation(bool dir);
 	virtual GLEDrawObject* clone();
 	virtual bool approx(GLEDrawObject* other);
+	virtual bool modified();
 	virtual void draw();
 
 	GLEDrawObject* deepClone();
@@ -946,6 +947,7 @@ protected:
 	string m_PostScript;
 	GLERectangle m_PSBoundingBox;
 	double m_BaseLine;
+	bool m_Modified;
 public:
 	GLETextDO();
 	GLETextDO(GLEPoint& position, const string& text);
@@ -969,6 +971,8 @@ public:
 	virtual void initProperties(GLEInterface* iface);
 	virtual GLEDrawObject* clone();
 	virtual bool approx(GLEDrawObject* other);
+	virtual bool modified();
+	DLLFCT void setModified(bool modified);
 	DLLFCT void render(GLEInterface* iface);
 };
 
