@@ -437,10 +437,12 @@ void handleNewDrawObject(GLEDrawObject* obj, bool mkdrobjs, GLEPoint* orig = NUL
 					if (orig != NULL) {
 						orig->set(amove);
 					}
-					string code;
-					nobj->createGLECode(code);
-					int line = g_get_error_line()-1;
-					source->updateLine(line, code);
+					if (mobj->modified()) {
+						string code;
+						nobj->createGLECode(code);
+						int line = g_get_error_line()-1;
+						source->updateLine(line, code);
+					}
 				}
 				if (mobj->hasFlag(GDO_FLAG_DELETED)) {
 					string code;
@@ -546,7 +548,7 @@ void GLERun::do_pcode(GLESourceLine &sline, int *srclin, int *pcode, int plen, i
 			    !(p == GLE_KW_BEGIN && i == OP_BEGIN_OBJECT) &&
 			    !(p == GLE_KW_BEGIN && i == 22)  // begin config
 			) {
-				g_open(getOutput(), sline.getFileName());
+				g_open(getOutput(), getSource()->getLocation()->getName());
 				done_open = true;
 			}
 		}
@@ -799,6 +801,10 @@ void GLERun::do_pcode(GLESourceLine &sline, int *srclin, int *pcode, int plen, i
 					readlong(jj);
 					if (jj == 0) {
 						/* dynamic object inside sub */
+						if (!done_open) {
+							g_open(getOutput(), getSource()->getLocation()->getName());
+							done_open = true;
+						}
 						readlong(jj);
 						readval(z);
 						begin_object(ostr, getSubroutines()->get(jj));
@@ -2027,7 +2033,6 @@ void GLERun::draw_object_static(const string& path, const string& name, int* pco
 	g_move(0.0, 0.0);
 	if (mkdrobjs) {
 		GLESub* sub = eval_subroutine_call(pcode, cp, &otyp);
-		// FIXME: should we do this?
 		sub->setScript(getScript());
 		GLEObjectDOConstructor* cons = sub->getObjectDOConstructor();
 		GLEObjectDO objdo(cons);
