@@ -127,6 +127,8 @@ TeXObject* TeXInterface::draw(const char* str, TeXObjectInfo& info, int nblines,
 	tryLoadHash();
 	/* Get object from hash */
 	string obj_str = str;
+	/* replace \'' by \" so that umlauts work in LaTeX expressions */
+	str_replace_all(obj_str, "\\''", "\\\"");
 	scaleObject(obj_str);
 	TeXHashObject* hobj = getHashObject(obj_str);
 	hobj->setNbLines(nblines);
@@ -253,6 +255,8 @@ int TeXInterface::createObj(const char* str) {
 	tryLoadHash();
 	/* Create object given string */
 	string obj_str = str;
+	/* replace \'' by \" so that umlauts work in LaTeX expressions */
+	str_replace_all(obj_str, "\\''", "\\\"");
 	scaleObject(obj_str);
 	int result = getHashObjectIndex(obj_str);
 	m_TeXHash[result]->setUsed(true);
@@ -551,7 +555,7 @@ bool TeXInterface::createTeXPS(const string& filestem) {
 	string dir, file;
 	SplitFileName(filestem, dir, file);
 	if (!run_latex(dir, file)) return false;
-	return run_dvips(filestem, "", false);
+	return run_dvips(filestem, false);
 }
 
 void TeXInterface::initTeXFontScales() {
@@ -1248,9 +1252,14 @@ bool create_pdf_file_pdflatex(const string& fname) {
 	string file, dir;
 	SplitFileName(fname, dir, file);
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
-	string pdftex_cmd = ((CmdLineArgString*)tools->getOptionValue(GLE_TOOL_PDFTEX_CMD))->getValue();
-	str_try_add_quote(pdftex_cmd);
-	string cmdline = pdftex_cmd + string(" \"") + file + ".tex\"";
+	string cmdline(get_tool_path(GLE_TOOL_PDFTEX_CMD, tools));
+	str_try_add_quote(cmdline);
+	const string pdftex_opts(tools->getOptionString(GLE_TOOL_PDFTEX_OPTIONS));
+	if (!pdftex_opts.empty()) {
+		cmdline += " ";
+		cmdline += pdftex_opts;
+	}
+	cmdline += string(" \"") + file + ".tex\"";
 	string outfile = file + ".pdf";
 	if (g_verbosity() >= 5) {
 		ostringstream msg;
@@ -1268,7 +1277,7 @@ bool create_pdf_file_pdflatex(const string& fname) {
 }
 
 bool run_latex(const string& dir, const string& file) {
-	string cmdline, crdir;
+	string crdir;
 	if (dir != "") {
 		GLEGetCrDir(&crdir);
 		if (!GLEChDir(dir)) {
@@ -1277,9 +1286,14 @@ bool run_latex(const string& dir, const string& file) {
 		}
 	}
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
-	string latex_cmd = ((CmdLineArgString*)tools->getOptionValue(GLE_TOOL_LATEX_CMD))->getValue();
-	str_try_add_quote(latex_cmd);
-	cmdline = latex_cmd + string(" \"") + file + ".tex\"";
+	string cmdline(get_tool_path(GLE_TOOL_LATEX_CMD, tools));
+	str_try_add_quote(cmdline);
+	const string latex_opts(tools->getOptionString(GLE_TOOL_LATEX_OPTIONS));
+	if (!latex_opts.empty()) {
+		cmdline += " ";
+		cmdline += latex_opts;
+	}
+	cmdline += string(" \"") + file + ".tex\"";
 	string outfile = file + ".dvi";
 	if (g_verbosity() >= 5) {
 		ostringstream msg;
@@ -1301,7 +1315,7 @@ bool create_eps_file_latex_dvips(const string& fname) {
 	CmdLineArgSet* texsys =	(CmdLineArgSet*)tex->getOptionValue(GLE_TEX_SYSTEM);
 	SplitFileName(fname, dir, file);
 	if (!run_latex(dir, file)) return false;
-	if (!run_dvips(fname, "", true)) return false;
+	if (!run_dvips(fname, true)) return false;
 	DeleteFileWithExt(fname, ".aux");
 	if (texsys->hasValue(GLE_TEX_SYSTEM_VTEX)) {
 	DeleteFileWithExt(fname, ".ps");
@@ -1318,7 +1332,7 @@ bool create_ps_file_latex_dvips(const string& fname) {
 	CmdLineArgSet* texsys =	(CmdLineArgSet*)tex->getOptionValue(GLE_TEX_SYSTEM);
 	SplitFileName(fname, dir, file);
 	if (!run_latex(dir, file)) return false;
-	if (!run_dvips(fname, "", false)) return false;
+	if (!run_dvips(fname, false)) return false;
 	DeleteFileWithExt(fname, ".aux");
 	if (!texsys->hasValue(GLE_TEX_SYSTEM_VTEX)) {
 		DeleteFileWithExt(fname, ".dvi");
@@ -1348,9 +1362,15 @@ void post_run_process(bool result_ok, const char* procname, const string& cmdlin
 
 bool run_ghostscript(const string& args, const string& outfile, bool redirout, istream* is) {
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
-	string gs_cmd = get_tool_path(GLE_TOOL_GHOSTSCRIPT_CMD, tools);
-	str_try_add_quote(gs_cmd);
-	string cmdline = gs_cmd + string(" ") + args;
+	string cmdline(get_tool_path(GLE_TOOL_GHOSTSCRIPT_CMD, tools));
+	str_try_add_quote(cmdline);
+	const string gs_opts(tools->getOptionString(GLE_TOOL_GHOSTSCRIPT_OPTIONS));
+	if (!gs_opts.empty()) {
+		cmdline += " ";
+		cmdline += gs_opts;
+	}
+	cmdline += " ";
+	cmdline += args;
 	if (g_verbosity() >= 5) {
 		ostringstream msg;
 		msg << "[Running: " << cmdline << "]";
@@ -1375,7 +1395,7 @@ bool run_ghostscript(const string& args, const string& outfile, bool redirout, i
 	return (result == GLE_SYSTEM_OK) && outfile_ok;
 }
 
-bool run_dvips(const string& file, const char* opts, bool eps) {
+bool run_dvips(const string& file, bool eps) {
 	ConfigSection* tex = g_Config.getSection(GLE_CONFIG_TEX);
 	CmdLineArgSet* texsys =	(CmdLineArgSet*)tex->getOptionValue(GLE_TEX_SYSTEM);
 	if (texsys->hasValue(GLE_TEX_SYSTEM_VTEX)) {
@@ -1397,14 +1417,17 @@ bool run_dvips(const string& file, const char* opts, bool eps) {
 			return true;
 		}
 	} else {
-		string outfile = file + (eps ? ".eps" : ".ps");
+		// get dvips command
 		ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
-		string dvips_cmd = ((CmdLineArgString*)tools->getOptionValue(GLE_TOOL_DVIPS_CMD))->getValue();
+		string dvips_cmd(get_tool_path(GLE_TOOL_DVIPS_CMD, tools));
 		str_try_add_quote(dvips_cmd);
+		// construct dvips arguments
 		ostringstream dvipsargs;
 		dvipsargs << dvips_cmd;
-		if (!str_i_equals(opts, "")) dvipsargs << " " << opts;
+		const string dvips_opts(tools->getOptionString(GLE_TOOL_DVIPS_OPTIONS));
+		if (!dvips_opts.empty()) dvipsargs << " " << dvips_opts;
 		if (eps) dvipsargs << " -E";
+		const string outfile = file + (eps ? ".eps" : ".ps");
 		dvipsargs << " -o \"" << outfile << "\" \"" << file << ".dvi\"";
 		string cmdline = dvipsargs.str();
 		if (g_verbosity() >= 5) {
