@@ -47,6 +47,9 @@ void SetQGLEScriptNameBackup(QString name);
 //! Class Constructor
 GLEMainWindow::GLEMainWindow(int argc, char *argv[])
 {
+	// Initially enabled state is false
+	enabledState = false;
+
 	// Resize to an initial default size
 	resize(500,300);
 
@@ -238,16 +241,18 @@ void GLEMainWindow::updateFileMonitor(bool state)
 {
 	if (state)
 	{
-		if (fileMonitorTimer->isActive())
-			return;
-		// One second timer
-		fileMonitorTimer->start(500);
+		if (!fileMonitorTimer->isActive())
+		{
+			// One second timer
+			fileMonitorTimer->start(500);
+		}
 	}
 	else
 	{
-		if (!fileMonitorTimer->isActive())
-			return;
-		fileMonitorTimer->stop();
+		if (fileMonitorTimer->isActive())
+		{
+			fileMonitorTimer->stop();
+		}
 	}
 	// used to wait another "tick" before auto-reloading
 	fileMonitorCount = 0;
@@ -263,7 +268,7 @@ void GLEMainWindow::checkForFileUpdates()
 {
 	int answer = 1;
 	GLEFileInfo* currFile = getCurrentFile();
-	if (currFile->hasChanged())
+	if (enabledState && currFile->hasChanged())
 	{
 		if (settings->monitorAutoReloadFile() && !askAnywayBeforeReload())
 		{
@@ -307,11 +312,13 @@ void GLEMainWindow::checkForFileUpdates()
 					QString(),
 					0,1);
 		}
+		bool isOpen = false;
 		switch(answer)
 		{
 			case 0:
 				qDebug() << "Reload file selected";
 				openFile(currFile->primaryFile());
+				isOpen = true;
 				break;
 			default:
 				qDebug() << "Ignore selected";
@@ -320,7 +327,7 @@ void GLEMainWindow::checkForFileUpdates()
 
 		// Restart the timer
 		currFile->updateTimeStamp();
-		fileMonitorTimer->start();
+		if (!isOpen) fileMonitorTimer->start();
 	}
 
 }
@@ -712,6 +719,7 @@ void GLEMainWindow::updateEnableActions(bool enable)
 	bool has = isGLE || getCurrentFile()->isEPS();
 	bool prevMode = (currentMode == GLESettings::PreviewMode);
 	bool figure = (previewPageSize->currentIndex() == 0);
+	enabledState = enable && has;
 	editorAct->setEnabled(has);
 	copyBitmapAct->setEnabled(has);
 	saveAsAct->setEnabled(has && enable);
@@ -737,14 +745,15 @@ void GLEMainWindow::updateEnableActions(bool enable)
 	ellipseToolAct->setEnabled(enable);
 	arcToolAct->setEnabled(enable);
 	textToolAct->setEnabled(enable);
-	if (!(has && enable)) {
-		if (has) {
+	bool reloadActEnable = has && enable && prevMode;
+	if (!reloadActEnable) {
+		if (has && prevMode) {
 			reloadAct->setIcon(reloadIconRed);
 		} else {
 			reloadAct->setIcon(reloadIconBlack);
 		}
 	}
-	reloadAct->setEnabled(has && enable);
+	reloadAct->setEnabled(reloadActEnable);
 }
 
 void GLEMainWindow::clearConsoleWindow()
@@ -1243,6 +1252,7 @@ void GLEMainWindow::enableEditModeToolBars(bool enable)
 	compatToolBar->setEnabled(!enable);
 	emulateVersion->setEnabled(!enable);
 	previewPageSize->setEnabled(!enable);
+	reloadAct->setEnabled(!enable);
 	if (enable)
 	{
 		// Enable first, then show
@@ -2062,7 +2072,9 @@ void GLEMainWindow::save(QString fileName)
 
 	// Restart the timer if appropriate
 	if (wasActive)
+	{
 		fileMonitorTimer->start();
+	}
 }
 
 // SLOT: Open file in new window
@@ -2083,11 +2095,6 @@ void GLEMainWindow::openFileInNewWindow()
 void GLEMainWindow::openFile(QString fileName, bool isOnStartup)
 {
 	qDebug() << "Open file " << fileName;
-	// Check if not busy with rendering
-	if (isBusy()) {
-		return;
-	}
-
 	bool isReload = (getCurrentGleFile() == fileName);
 
 	// If changes have been made, ask what to do
@@ -2100,9 +2107,14 @@ void GLEMainWindow::openFile(QString fileName, bool isOnStartup)
 				QMessageBox::Cancel);
 
 		if (reply == QMessageBox::Yes)
+		{
 			save();
+		}
 		else if (reply == QMessageBox::Cancel)
+		{
+			updateFileMonitor(settings->monitorOpenFile());
 			return;
+		}
 	}
 
 	// If we don't have a filename (i.e. if called as a slot rather than
@@ -2144,10 +2156,7 @@ void GLEMainWindow::openFile(QString fileName, bool isOnStartup)
 		todoList.append(ToDoAfterFileOpen);
 
 		// Stop the timer
-		if (fileMonitorTimer->isActive())
-		{
-			fileMonitorTimer->stop();
-		}
+		updateFileMonitor(false);
 
 		// An EPS file, so open it.
 		GLEFileInfo* currFile = getCurrentFile();
@@ -2184,11 +2193,6 @@ void GLEMainWindow::openFile(QString fileName, bool isOnStartup)
 // SLOT: Create a blank page
 void GLEMainWindow::newFile()
 {
-	// Check if not busy with rendering
-	if (isBusy()) {
-		return;
-	}
-
 	// Should we save changes?
 	if (drawingArea->isDirty())
 	{
@@ -2222,10 +2226,7 @@ void GLEMainWindow::newFile()
 	}
 
 	// Stop the timer
-	if (fileMonitorTimer->isActive())
-	{
-		fileMonitorTimer->stop();
-	}
+	updateFileMonitor(false);
 
 	resetDrawing();
 	newDiagramSize = nfb.size();
