@@ -76,33 +76,20 @@ void GLEObjectBlocksList::selectEntry(const QModelIndex& mi) {
 	scrollSize.setHeight(min(scrollSize.height(), drawSize.height()));
 	QPoint pos = QPoint(scrollSize.width()/2-drawPos.x(), scrollSize.height()/2-drawPos.y());
 	block->setPoint(GLEObjectBlock::ReferencePoint, pos, false);
-	GLEPropertyStore* props = block->getGLEObject()->getProperties();
+	GLEObjectDO* obj = (GLEObjectDO*)block->getGLEObject();
+	GLEPropertyStore* props = obj->getProperties();
 	if (props->getModel()->isSupportScale()) {
 		GLEArrayImpl* arr = props->getArray();
 		block->setLength(GLEObjectBlock::ObjectWidth, arr->getDouble(0), false);
 		block->setLength(GLEObjectBlock::ObjectHeight, arr->getDouble(1), false);
 	}
-	block->updateObject();
+	block->updateFromPropertyNoDirty(GLEObjectBlock::RefPointName);
 	// Select object
 	mainWin->selectPointerTool();
 	drawingArea->selectObject(block);
 	drawingArea->update();
 }
 
-/*
-QSize GLEObjectBlocksList::sizeHint() const
-{
-	qDebug() << "Default size object blocks: " << defaultSize;
-	if (defaultSize == 0) return QTreeView::sizeHint();
-	return QSize(250, defaultSize);
-}
-
-int GLEObjectBlocksList::heightForWidth(int) const
-{
-	return -1;
-}
-*/
-
 // The constructor for the line object
 GLEObjectBlock::GLEObjectBlock(double resolution, QSize imageSize, GLEDrawingArea* area)
 	: GLEDrawingObject(resolution, imageSize, area)
@@ -184,7 +171,6 @@ void GLEObjectBlock::updateFromPropertyNoDirty(int property)
 		QGLE::qtToGLEString(refPtStr, refPtStrGLE.get());
 		obj->setRefPointString(refPtStrGLE.get());
 		obj->computeReferencePoint(&referenceOffset);
-		qDebug() << "Reference point in GLE object: " << referenceOffset.getX() << " " << referenceOffset.getY();
 	}
 
 	if (property == LineWidth || property == LineColour || property == FillColour || property == FontName ||
@@ -238,6 +224,20 @@ void GLEObjectBlock::updateObject()
 	updateObjectScale(1.0, 1.0);
 }
 
+/**
+ * referenceOffset: offset of reference point (justify setting) in cm measured from bottom-left corner
+ * referencePoint:  reference point on screen
+ * scriptPosition:  referencePoint + referenceOffset
+ * drawpoint:       where to draw pixmap on screen
+ *
+ * screen:
+ *
+ * (0,0).............(maxx,0)
+ * .                 .
+ * .                 .
+ * (0,maxy)..........(maxx,maxy)
+ */
+
 // Update the painter path
 void GLEObjectBlock::updateObjectScale(double sx, double sy)
 {
@@ -468,7 +468,6 @@ QList<QPointF> GLEObjectBlock::intersections(QPointF qtp1, double angle)
 	UNUSED_ARG(qtp1);
 	UNUSED_ARG(angle);
 	return QList<QPointF>();
-
 }
 
 bool GLEObjectBlock::isInside(QPointF p)
@@ -495,25 +494,18 @@ void GLEObjectBlock::linearTransform(const GLELinearEquation& ex, const GLELinea
 		/* Something's wrong */
 		return;
 	}
-	/*
-	qDebug() << "**** New scale";
-	qDebug() << " NewSize: " << wd << " " << hi;
-	qDebug() << " ScaleOffs: " << scaleOffs.x() << " " << scaleOffs.y();
-	qDebug() << " Scale: " << ex.getA() << " " << ey.getA() << " " << ex.getB() << " " << ey.getB();
-	*/
 	double sx = ex.getA()/scaleOffs.x();
 	double sy = ey.getA()/scaleOffs.y();
+	GLEObjectDO* obj = (GLEObjectDO*)getGLEObject();
 	if (wd != getGLELength(ObjectWidth, false) || hi != getGLELength(ObjectHeight, false))
 	{
 		setLength(ObjectWidth, wd, false);
 		setLength(ObjectHeight, hi, false);
-		GLEObjectDO* obj = (GLEObjectDO*)getGLEObject();
 		obj->getProperties()->getModel()->scale(obj, wd, hi);
 		int int_wd = (int)floor(origImage.width()*sx+0.5);
 		int int_hi = (int)floor(origImage.height()*sy+0.5);
 		if (sx < 0.5 || sx > 2.0 || sy < 0.5 || sy > 2.0) {
 			/* deviation too big -> rerender */
-			GLEObjectDO* obj = (GLEObjectDO*)getGLEObject();
 			obj->render();
 			renderPostscriptNoUpdate();
 			scaleOffs = QPointF(ex.getA(), ey.getA());
@@ -530,6 +522,7 @@ void GLEObjectBlock::linearTransformDone()
 {
 	GLEObjectDO* obj = (GLEObjectDO*)getGLEObject();
 	obj->render();
+	obj->computeReferencePoint(&referenceOffset);
 	renderPostscript();
 }
 
